@@ -764,7 +764,13 @@ free(void * address)
 extern C_LINKAGE void *
 realloc(void * oldBuffer, size_t newSize)
 {
-	void *	newBuffer = malloc(newSize);
+ 	void *	newBuffer;
+ 	
+ 	if (oldBuffer && newSize==0) {
+ 		free(oldBuffer);
+ 		return NULL;
+ 	}
+ 	newBuffer = malloc(newSize);
 
         lock();
 
